Skip to main contentModule crypto
Source - Keys
- RSA key pair used for signing and verifying JWT access tokens.
- build_jwks_json
- Build the JWKS JSON document (public keys) for a given key set.
- calculate_at_hash
- Calculate at_hash (Access Token Hash) per OIDC Core Section 3.2.2.9.
Used to validate that an access token was issued alongside an ID token.
- calculate_c_hash
- Calculate c_hash (Code Hash) per OIDC Core Section 3.2.2.9.
Used to validate that an authorization code was issued alongside an ID token.
- generate_code
- Generate a short authorization code.
- generate_token_string
- Generate an opaque access/refresh token string.
- issue_id_token
- Sign and return an ID Token per OpenID Connect Core 1.0.
- issue_jwt
- Sign and return a JWT access token.